@@ -1,4 +1,4 @@
-c.bma <-
+`c.bma` <-
 function (..., recursive = FALSE) 
 {
     combine_chains(...)
