@@ -1,4 +1,4 @@
-estimates.bma <-
+`estimates.bma` <-
 function (bmao, exact = FALSE, order.by.pip = TRUE, include.constant = FALSE, 
     incl.possign = TRUE, std.coefs = FALSE, condi.coef = FALSE) 
 {
